==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/nn_NO.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Kunne ikkje snede e-post til følgande brukarar: %s ",
    "Turned on maintenance mode" : "Skrudde på vedlikehaldsmodus",
    "Turned off maintenance mode" : "Skrudde av vedlikehaldsmodus",
    "Updated database" : "Database oppdatert",
    "No image or file provided" : "Inga bilete eller fil gjeve",
    "Unknown filetype" : "Ukjend filtype",
    "Invalid image" : "Ugyldig bilete",
    "No temporary profile picture available, try again" : "Inga midlertidig profilbilete tilgjengeleg, prøv igjen",
    "No crop data provided" : "Ingen beskjeringsdata gjeve",
    "Sunday" : "Søndag",
    "Monday" : "Måndag",
    "Tuesday" : "Tysdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Laurdag",
    "Sun." : "Søn.",
    "Mon." : "Mån.",
    "Tue." : "Tys.",
    "Wed." : "Ons.",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lau.",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mars",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar,",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "Settings" : "Innstillingar",
    "Saving..." : "Lagrar …",
    "seconds ago" : "sekund sidan",
    "I know what I'm doing" : "Eg veit kva eg gjer",
    "No" : "Nei",
    "Yes" : "Ja",
    "Choose" : "Vel",
    "Error loading file picker template: {error}" : "Klarte ikkje å lasta filplukkarmal: {error}",
    "Ok" : "Greitt",
    "Error loading message template: {error}" : "Klarte ikkje å lasta meldingsmal: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} filkonfliktar"],
    "One file conflict" : "Éin filkonflikt",
    "Which files do you want to keep?" : "Kva filer vil du spara?",
    "If you select both versions, the copied file will have a number added to its name." : "Viss du vel begge utgåvene, vil den kopierte fila få eit tal lagt til namnet.",
    "Cancel" : "Avbryt",
    "Continue" : "Gå vidare",
    "(all selected)" : "(alle valte)",
    "({count} selected)" : "({count} valte)",
    "Error loading file exists template" : "Klarte ikkje å lasta fil-finst-mal",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "Shared" : "Delt",
    "Error" : "Feil",
    "Error while sharing" : "Feil ved deling",
    "Error while unsharing" : "Feil ved udeling",
    "Error while changing permissions" : "Feil ved endring av tillatingar",
    "Error setting expiration date" : "Klarte ikkje setja utløpsdato",
    "Set expiration date" : "Set utløpsdato",
    "Expiration date" : "Utløpsdato",
    "Sending ..." : "Sender …",
    "Email sent" : "E-post sendt",
    "Resharing is not allowed" : "Vidaredeling er ikkje tillate",
    "Share link" : "Del lenkje",
    "Password protect" : "Passordvern",
    "Password" : "Passord",
    "Choose a password for the public link" : "Vel eit passord for den offentlege lenkja",
    "Email link to person" : "Send lenkja over e-post",
    "Send" : "Send",
    "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppa {group} av {owner}",
    "Shared with you by {owner}" : "Delt med deg av {owner}",
    "Shared in {item} with {user}" : "Delt i {item} med {brukar}",
    "group" : "gruppe",
    "Unshare" : "Udel",
    "can share" : "kan dela",
    "can edit" : "kan endra",
    "create" : "lag",
    "delete" : "slett",
    "access control" : "tilgangskontroll",
    "Share" : "Del",
    "Warning" : "Åtvaring",
    "The object type is not specified." : "Objekttypen er ikkje spesifisert.",
    "Delete" : "Slett",
    "Add" : "Legg til",
    "The update was successful. Redirecting you to ownCloud now." : "Oppdateringa er fullført. Sender deg vidare til ownCloud no.",
    "%s password reset" : "%s passordnullstilling",
    "Use the following link to reset your password: {link}" : "Klikk følgjande lenkje til å nullstilla passordet ditt: {link}",
    "New password" : "Nytt passord",
    "Reset password" : "Nullstill passord",
    "Personal" : "Personleg",
    "Users" : "Brukarar",
    "Apps" : "Program",
    "Admin" : "Admin",
    "Help" : "Hjelp",
    "Access forbidden" : "Tilgang forbudt",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datamappa og filene dine er sannsynlegvis tilgjengelege frå Internett sidan .htaccess-fila ikkje fungerer.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Ver venleg og les <a href=\"%s\" target=\"_blank\">dokumentasjonen</a> for meir informasjon om korleis du konfigurerer tenaren din.",
    "Create an <strong>admin account</strong>" : "Lag ein <strong>admin-konto</strong>",
    "Username" : "Brukarnamn",
    "Data folder" : "Datamappe",
    "Configure the database" : "Set opp databasen",
    "Database user" : "Databasebrukar",
    "Database password" : "Databasepassord",
    "Database name" : "Databasenamn",
    "Database tablespace" : "Tabellnamnrom for database",
    "Database host" : "Databasetenar",
    "Finish setup" : "Fullfør oppsettet",
    "Log out" : "Logg ut",
    "Search" : "Søk",
    "Log in" : "Logg inn",
    "remember" : "hugs",
    "Alternative Logins" : "Alternative innloggingar"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/nn_NO.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Kunne ikkje snede e-post til følgande brukarar: %s ",
    "Turned on maintenance mode" : "Skrudde på vedlikehaldsmodus",
    "Turned off maintenance mode" : "Skrudde av vedlikehaldsmodus",
    "Updated database" : "Database oppdatert",
    "No image or file provided" : "Inga bilete eller fil gjeve",
    "Unknown filetype" : "Ukjend filtype",
    "Invalid image" : "Ugyldig bilete",
    "No temporary profile picture available, try again" : "Inga midlertidig profilbilete tilgjengeleg, prøv igjen",
    "No crop data provided" : "Ingen beskjeringsdata gjeve",
    "%s password reset" : "%s passordnullstilling",
    "Sunday" : "Søndag",
    "Monday" : "Måndag",
    "Tuesday" : "Tysdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Laurdag",
    "Sun." : "Søn.",
    "Mon." : "Mån.",
    "Tue." : "Tys.",
    "Wed." : "Ons.",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lau.",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mars",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar,",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "Settings" : "Innstillingar",
    "Saving..." : "Lagrar …",
    "seconds ago" : "sekund sidan",
    "I know what I'm doing" : "Eg veit kva eg gjer",
    "No" : "Nei",
    "Yes" : "Ja",
    "Choose" : "Vel",
    "Error loading file picker template: {error}" : "Klarte ikkje å lasta filplukkarmal: {error}",
    "Ok" : "Greitt",
    "Error loading message template: {error}" : "Klarte ikkje å lasta meldingsmal: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} filkonfliktar"],
    "One file conflict" : "Éin filkonflikt",
    "Which files do you want to keep?" : "Kva filer vil du spara?",
    "If you select both versions, the copied file will have a number added to its name." : "Viss du vel begge utgåvene, vil den kopierte fila få eit tal lagt til namnet.",
    "Cancel" : "Avbryt",
    "Continue" : "Gå vidare",
    "(all selected)" : "(alle valte)",
    "({count} selected)" : "({count} valte)",
    "Error loading file exists template" : "Klarte ikkje å lasta fil-finst-mal",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "Shared" : "Delt",
    "Error" : "Feil",
    "Error while sharing" : "Feil ved deling",
    "Error while unsharing" : "Feil ved udeling",
    "Error setting expiration date" : "Klarte ikkje setja utløpsdato",
    "Set expiration date" : "Set utløpsdato",
    "Expiration date" : "Utløpsdato",
    "Choose a password for the public link" : "Vel eit passord for den offentlege lenkja",
    "Sending ..." : "Sender …",
    "Email sent" : "E-post sendt",
    "Resharing is not allowed" : "Vidaredeling er ikkje tillate",
    "Share link" : "Del lenkje",
    "Password protect" : "Passordvern",
    "Password" : "Passord",
    "Email link to person" : "Send lenkja over e-post",
    "Send" : "Send",
    "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppa {group} av {owner}",
    "Shared with you by {owner}" : "Delt med deg av {owner}",
    "group" : "gruppe",
    "Unshare" : "Udel",
    "can share" : "kan dela",
    "can edit" : "kan endra",
    "create" : "lag",
    "delete" : "slett",
    "access control" : "tilgangskontroll",
    "Share" : "Del",
    "Warning" : "Åtvaring",
    "Delete" : "Slett",
    "Rename" : "Endra namn",
    "The object type is not specified." : "Objekttypen er ikkje spesifisert.",
    "Add" : "Legg til",
    "The update was successful. Redirecting you to ownCloud now." : "Oppdateringa er fullført. Sender deg vidare til ownCloud no.",
    "Personal" : "Personleg",
    "Users" : "Brukarar",
    "Apps" : "Program",
    "Admin" : "Admin",
    "Help" : "Hjelp",
    "Access forbidden" : "Tilgang forbudt",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datamappa og filene dine er sannsynlegvis tilgjengelege frå Internett sidan .htaccess-fila ikkje fungerer.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Ver venleg og les <a href=\"%s\" target=\"_blank\">dokumentasjonen</a> for meir informasjon om korleis du konfigurerer tenaren din.",
    "Create an <strong>admin account</strong>" : "Lag ein <strong>admin-konto</strong>",
    "Username" : "Brukarnamn",
    "Data folder" : "Datamappe",
    "Configure the database" : "Set opp databasen",
    "Database user" : "Databasebrukar",
    "Database password" : "Databasepassord",
    "Database name" : "Databasenamn",
    "Database tablespace" : "Tabellnamnrom for database",
    "Database host" : "Databasetenar",
    "Finish setup" : "Fullfør oppsettet",
    "Log out" : "Logg ut",
    "Search" : "Søk",
    "Log in" : "Logg inn",
    "Alternative Logins" : "Alternative innloggingar",
    "Use the following link to reset your password: {link}" : "Klikk følgjande lenkje til å nullstilla passordet ditt: {link}",
    "New password" : "Nytt passord",
    "Reset password" : "Nullstill passord"
},
"nplurals=2; plural=(n != 1);");
